/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Corporation startup cache code.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Benedict Hsieh <bhsieh@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIInputStream.idl"
#include "nsISupports.idl"
#include "nsIObserver.idl"
#include "nsIObjectOutputStream.idl"

[uuid(de798fab-af49-4a61-8144-81550986e1da)]
interface nsIStartupCache : nsISupports
{

  /** This interface is provided for testing purposes only, basically
   *  just to solve link vagaries. See docs in StartupCache.h
   *  GetBuffer, PutBuffer, and InvalidateCache act as described 
   *  in that file. */

  PRUint32 getBuffer(in string aID, out charPtr aBuffer);
  void putBuffer(in string aID, in charPtr aBuffer, 
                            in PRUint32 aLength);
 
  void invalidateCache();
  
  /** In debug builds, wraps this object output stream with a stream that will 
   *  detect and prevent the write of a multiply-referenced non-singleton object 
   *  during serialization. In non-debug, returns an add-ref'd pointer to
   *  original stream, unwrapped. */
  nsIObjectOutputStream getDebugObjectOutputStream(in nsIObjectOutputStream aStream);

  /* Allows clients to check whether the one-time writeout after startup 
   * has finished yet, and also to set this variable as needed (so test
   * code can fire mulitple startup writes if needed).
   */
  boolean startupWriteComplete();
  void resetStartupWriteTimer();

  /* Allows clients to simulate the behavior of ObserverService. */
  readonly attribute nsIObserver observer;
};

